package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.PrivateKeyInfo;
import cn.com.infosec.asn1.pkcs.RSAPrivateKeyStructure;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.crypto.params.RSAKeyParameters;
import cn.com.infosec.crypto.params.RSAPrivateCrtKeyParameters;
import java.math.BigInteger;
import java.security.interfaces.RSAPrivateCrtKey;
import java.security.spec.RSAPrivateCrtKeySpec;

public class JCERSAPrivateCrtKey extends JCERSAPrivateKey implements RSAPrivateCrtKey {
   static final long serialVersionUID = 7834723820638524718L;
   private BigInteger publicExponent;
   private BigInteger primeP;
   private BigInteger primeQ;
   private BigInteger primeExponentP;
   private BigInteger primeExponentQ;
   private BigInteger crtCoefficient;

   JCERSAPrivateCrtKey(RSAPrivateCrtKeyParameters key) {
      super((RSAKeyParameters)key);
      this.publicExponent = key.getPublicExponent();
      this.primeP = key.getP();
      this.primeQ = key.getQ();
      this.primeExponentP = key.getDP();
      this.primeExponentQ = key.getDQ();
      this.crtCoefficient = key.getQInv();
   }

   JCERSAPrivateCrtKey(RSAPrivateCrtKeySpec spec) {
      super.modulus = spec.getModulus();
      this.publicExponent = spec.getPublicExponent();
      super.privateExponent = spec.getPrivateExponent();
      this.primeP = spec.getPrimeP();
      this.primeQ = spec.getPrimeQ();
      this.primeExponentP = spec.getPrimeExponentP();
      this.primeExponentQ = spec.getPrimeExponentQ();
      this.crtCoefficient = spec.getCrtCoefficient();
   }

   JCERSAPrivateCrtKey(RSAPrivateCrtKey key) {
      super.modulus = key.getModulus();
      this.publicExponent = key.getPublicExponent();
      super.privateExponent = key.getPrivateExponent();
      this.primeP = key.getPrimeP();
      this.primeQ = key.getPrimeQ();
      this.primeExponentP = key.getPrimeExponentP();
      this.primeExponentQ = key.getPrimeExponentQ();
      this.crtCoefficient = key.getCrtCoefficient();
   }

   JCERSAPrivateCrtKey(PrivateKeyInfo info) {
      this(new RSAPrivateKeyStructure((ASN1Sequence)info.getPrivateKey()));
   }

   JCERSAPrivateCrtKey(RSAPrivateKeyStructure key) {
      super.modulus = key.getModulus();
      this.publicExponent = key.getPublicExponent();
      super.privateExponent = key.getPrivateExponent();
      this.primeP = key.getPrime1();
      this.primeQ = key.getPrime2();
      this.primeExponentP = key.getExponent1();
      this.primeExponentQ = key.getExponent2();
      this.crtCoefficient = key.getCoefficient();
   }

   public String getFormat() {
      return "PKCS#8";
   }

   public byte[] getEncoded() {
      AlgorithmIdentifier var10002 = new AlgorithmIdentifier(PKCSObjectIdentifiers.rsaEncryption, new DERNull());
      JCERSAPrivateCrtKey var10005 = this;
      JCERSAPrivateCrtKey var10006 = this;
      JCERSAPrivateCrtKey var10007 = this;
      JCERSAPrivateCrtKey var10008 = this;
      JCERSAPrivateCrtKey var10009 = this;
      JCERSAPrivateCrtKey var10010 = this;
      JCERSAPrivateCrtKey var10011 = this;
      BigInteger var8 = this.getModulus();
      BigInteger var1 = var10011.getPublicExponent();
      BigInteger var2 = var10010.getPrivateExponent();
      BigInteger var3 = var10009.getPrimeP();
      BigInteger var4 = var10008.getPrimeQ();
      BigInteger var5 = var10007.getPrimeExponentP();
      BigInteger var6 = var10006.getPrimeExponentQ();
      BigInteger var7 = var10005.getCrtCoefficient();
      return (new PrivateKeyInfo(var10002, (new RSAPrivateKeyStructure(var8, var1, var2, var3, var4, var5, var6, var7)).getDERObject())).getDEREncoded();
   }

   public BigInteger getPublicExponent() {
      return this.publicExponent;
   }

   public BigInteger getPrimeP() {
      return this.primeP;
   }

   public BigInteger getPrimeQ() {
      return this.primeQ;
   }

   public BigInteger getPrimeExponentP() {
      return this.primeExponentP;
   }

   public BigInteger getPrimeExponentQ() {
      return this.primeExponentQ;
   }

   public BigInteger getCrtCoefficient() {
      return this.crtCoefficient;
   }

   public int hashCode() {
      return this.getModulus().hashCode() ^ this.getPublicExponent().hashCode() ^ this.getPrivateExponent().hashCode();
   }

   public boolean equals(Object o) {
      if (o == this) {
         return true;
      } else if (!(o instanceof RSAPrivateCrtKey)) {
         return false;
      } else {
         RSAPrivateCrtKey o1 = (RSAPrivateCrtKey)o;
         return this.getModulus().equals(o1.getModulus()) && this.getPublicExponent().equals(o1.getPublicExponent()) && this.getPrivateExponent().equals(o1.getPrivateExponent()) && this.getPrimeP().equals(o1.getPrimeP()) && this.getPrimeQ().equals(o1.getPrimeQ()) && this.getPrimeExponentP().equals(o1.getPrimeExponentP()) && this.getPrimeExponentQ().equals(o1.getPrimeExponentQ()) && this.getCrtCoefficient().equals(o1.getCrtCoefficient());
      }
   }

   public String toString() {
      StringBuffer var10000 = new StringBuffer();
      String var1 = System.getProperty("line.separator");
      var10000.append("RSA Private CRT Key").append(var1);
      var10000.append("            modulus: ").append(this.getModulus().toString(16)).append(var1);
      var10000.append("    public exponent: ").append(this.getPublicExponent().toString(16)).append(var1);
      var10000.append("   private exponent: ").append(this.getPrivateExponent().toString(16)).append(var1);
      var10000.append("             primeP: ").append(this.getPrimeP().toString(16)).append(var1);
      var10000.append("             primeQ: ").append(this.getPrimeQ().toString(16)).append(var1);
      var10000.append("     primeExponentP: ").append(this.getPrimeExponentP().toString(16)).append(var1);
      var10000.append("     primeExponentQ: ").append(this.getPrimeExponentQ().toString(16)).append(var1);
      var10000.append("     crtCoefficient: ").append(this.getCrtCoefficient().toString(16)).append(var1);
      return var10000.toString();
   }
}
